# Kaleidoscope

import board, neopixel, time, busio, digitalio, adafruit_lis3dh
from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile

#configure the speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

path = "ksounds/"

# set up accelerometer
i2c = busio.I2C(board.ACCELEROMETER_SCL, board.ACCELEROMETER_SDA)
int1 = digitalio.DigitalInOut(board.ACCELEROMETER_INTERRUPT)
accelerometer = adafruit_lis3dh.LIS3DH_I2C(i2c, address=0x19, int1=int1)
accelerometer.range = adafruit_lis3dh.RANGE_8_G

from adafruit_led_animation.color import (
    AMBER, #(255, 100, 0)
    AQUA, # (50, 255, 255)
    BLACK, #OFF (0, 0, 0)
    BLUE, # (0, 0, 255)
    CYAN, # (0, 255, 255)
    GOLD, # (255, 222, 30)
    GREEN, # (0, 255, 0)
    JADE, # (0, 255, 40)
    MAGENTA, #(255, 0, 20)
    OLD_LACE, # (253, 245, 230)
    ORANGE, # (255, 40, 0)
    PINK, # (242, 90, 255)
    PURPLE, # (180, 0, 255)
    RED, # (255, 0, 0)
    TEAL, # (0, 255, 120)
    WHITE, # (255, 255, 255)
    YELLOW, # (255, 150, 0)
    RAINBOW # a list of colors to cycle through
    # RAINBOW is RED, ORANGE, YELLOW, GREEN, BLUE, and PURPLE ((255, 0, 0), (255, 40, 0), (255, 150, 0), (0, 255, 0), (0, 0, 255), (180, 0, 255))
)

INDIGO = (63, 0, 255)
VIOLET = (127, 0, 255)
HOTPINK = (255, 51, 153)
PALEORANGE = (255, 178, 102)
BRIGHTYELLOW = (255, 255, 0)
LIGHTPURPLE = (178, 102, 255)
BLACK = (0, 0, 0)

warm = [MAGENTA, RED, ORANGE, AMBER, YELLOW, GOLD, PALEORANGE, HOTPINK, PINK, OLD_LACE]
cool = [GREEN, JADE, TEAL, AQUA, BLUE, CYAN, INDIGO, VIOLET, LIGHTPURPLE, PURPLE]

pixels_pin = board.NEOPIXEL
pixels_num_of_lights = 10
pixels = neopixel.NeoPixel(pixels_pin, pixels_num_of_lights)

def play_sound(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            pass

def left():
    for i in range(10):
        pixels[i] = warm[i]
        time.sleep(0.1)

def right():
    for i in range(10):
        pixels[i] = cool[i]
        time.sleep(0.1)

while True:
    x, y, z = accelerometer.acceleration
    print((x, y, z))
    if x < -3.0:
        left()
        play_sound("chime.wav")
        time.sleep(1.0)
    if x > 3.0:
        right()
        play_sound("laser_x.wav")
        time.sleep(1.0)
    else:
        pixels.fill(BLACK)
